@@ -5,3 +5,6 @@ Constants for outcome_surveys.
 SEGMENT_LEARNER_PASSED_COURSE_FIRST_TIME_EVENT_TYPE = 'edx.course.learner.passed.first_time'
 SEGMENT_LEARNER_PASSED_COURSE_FIRST_TIME_FOLLOW_UP_EVENT_TYPE = 'edx.course.learner.passed.first_time.followup'
 OUTCOME_SURVEYS_FOLLOW_UP_DAYS_DEFAULT = 90
+
+ENROLLMENT_TYPE_B2B = 'B2B'
+ENROLLMENT_TYPE_B2C = 'B2C'
